==> react-native-web-jsonschema-form-2.0.1.tgz: package/widgets/ScheduleWidget/CheckAll.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import Screen from 'react-native-web-ui-components/Screen';
import Column from 'react-native-web-ui-components/Column';
import fillSchedule from './fillSchedule';
import CheckboxWidget from '../CheckboxWidget';
const styles = StyleSheet.create({
  checkAll: {
    paddingTop: Screen.getType() === 'xs' ? 0 : 10
  }
});

const useOnChange = ({
  name,
  onChange,
  dateAttribute,
  timesAttribute,
  propertyUiSchema,
  scheduleParser
}) => checked => {
  const {
    checkAll
  } = propertyUiSchema['ui:options'];

  if (checkAll) {
    let checkAllValue;

    if (checked) {
      checkAllValue = fillSchedule(checkAll.value || [], timesAttribute, dateAttribute);
    } else {
      checkAllValue = fillSchedule([], timesAttribute, dateAttribute);
    }

    onChange(scheduleParser(checkAllValue), name);
  }
};

const CheckAll = props => {
  const {
    name,
    value,
    onFocus,
    dateAttribute,
    timesAttribute,
    propertyUiSchema
  } = props;
  const onChange = useOnChange(props);
  const {
    checkAll
  } = propertyUiSchema['ui:options'];

  if (!checkAll) {
    return null;
  }

  const length = checkAll.value && checkAll.value.length || 0;
  const checkAllValue = fillSchedule(checkAll.value || [], timesAttribute, dateAttribute);
  let checked = true;

  if (checkAllValue.length > value.length) {
    checked = false;
  } else {
    for (let i = 0; checked && i < length; i += 1) {
      if (checkAllValue[i][dateAttribute] !== value[i][dateAttribute] || (value[i][timesAttribute] || '').indexOf(checkAllValue[i][timesAttribute]) < 0) {
        checked = false;
      }
    }
  }

  const schema = {
    type: 'boolean'
  };
  const uiSchema = {};
  return React.createElement(Column, {
    xs: 12
  }, React.createElement(CheckboxWidget, {
    schema: schema,
    uiSchema: uiSchema,
    hasError: false,
    onFocus: onFocus,
    onChange: onChange,
    name: `${name}__checkAll`,
    gridItemType: "column",
    gridItemLength: 1,
    value: true,
    text: checkAll.label,
    checked: checked,
    style: styles.checkAll
  }));
};

CheckAll.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  onFocus: PropTypes.func.isRequired,
  dateAttribute: PropTypes.string.isRequired,
  timesAttribute: PropTypes.string.isRequired,
  propertyUiSchema: PropTypes.shape().isRequired
};
export default CheckAll;

==> react-native-web-jsonschema-form-2.0.18.tgz: package/widgets/ScheduleWidget/CheckAll.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import Screen from 'react-native-web-ui-components/Screen';
import Column from 'react-native-web-ui-components/Column';
import fillSchedule from './fillSchedule';
import { useAutoFocus } from '../../utils';
import CheckboxWidget from '../CheckboxWidget';
const styles = StyleSheet.create({
  checkAll: {
    paddingTop: Screen.getType() === 'xs' ? 0 : 10
  }
});

const useOnChange = ({
  name,
  onChange,
  dateAttribute,
  timesAttribute,
  propertyUiSchema,
  scheduleParser
}) => checked => {
  const {
    checkAll
  } = propertyUiSchema['ui:options'];

  if (checkAll) {
    let checkAllValue;

    if (checked) {
      checkAllValue = fillSchedule(checkAll.value || [], timesAttribute, dateAttribute);
    } else {
      checkAllValue = fillSchedule([], timesAttribute, dateAttribute);
    }

    onChange(scheduleParser(checkAllValue), name);
  }
};

const CheckAll = props => {
  const {
    name,
    value,
    dateAttribute,
    timesAttribute,
    propertyUiSchema
  } = props;
  const onChange = useOnChange(props);
  const autoFocusParams = useAutoFocus(props);
  const {
    checkAll
  } = propertyUiSchema['ui:options'];

  if (!checkAll) {
    return null;
  }

  const length = checkAll.value && checkAll.value.length || 0;
  const checkAllValue = fillSchedule(checkAll.value || [], timesAttribute, dateAttribute);
  let checked = true;

  if (checkAllValue.length > value.length) {
    checked = false;
  } else {
    for (let i = 0; checked && i < length; i += 1) {
      if (checkAllValue[i][dateAttribute] !== value[i][dateAttribute] || (value[i][timesAttribute] || '').indexOf(checkAllValue[i][timesAttribute]) < 0) {
        checked = false;
      }
    }
  }

  const schema = {
    type: 'boolean'
  };
  const uiSchema = {};
  return React.createElement(Column, {
    xs: 12
  }, React.createElement(CheckboxWidget, _extends({}, autoFocusParams, {
    schema: schema,
    uiSchema: uiSchema,
    hasError: false,
    onChange: onChange,
    name: `${name}__checkAll`,
    gridItemType: "column",
    gridItemLength: 1,
    value: true,
    text: checkAll.label,
    checked: checked,
    style: styles.checkAll
  })));
};

CheckAll.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  dateAttribute: PropTypes.string.isRequired,
  timesAttribute: PropTypes.string.isRequired,
  propertyUiSchema: PropTypes.shape().isRequired
};
export default CheckAll;
